@@ -26,10 +26,7 @@
 #include "config.h"
 #include "privacy-resources.h"
 #include "gis-privacy-page.h"
-
-#ifdef HAVE_WEBKITGTK
-#include <webkit/webkit.h>
-#endif
+#include "gis-webkit.h"
 
 #include <locale.h>
 #include <gtk/gtk.h>
@@ -52,77 +49,6 @@ struct _GisPrivacyPage
 
 G_DEFINE_TYPE (GisPrivacyPage, gis_privacy_page, GIS_TYPE_PAGE);
 
-#ifdef HAVE_WEBKITGTK
-static void
-notify_progress_cb (GObject *object, GParamSpec *pspec, gpointer user_data)
-{
-  GtkWidget *progress_bar = user_data;
-  WebKitWebView *web_view = WEBKIT_WEB_VIEW (object);
-  gdouble progress;
-
-  progress = webkit_web_view_get_estimated_load_progress (web_view);
-
-  gtk_widget_set_visible (progress_bar, progress != 1.0);
-  gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (progress_bar), progress);
-}
-
-static gboolean
-activate_link (GtkLabel       *label,
-               const gchar    *uri,
-               GisPrivacyPage *page)
-{
-  GtkWidget *headerbar;
-  GtkWidget *dialog;
-  GtkWidget *overlay;
-  GtkWidget *view;
-  GtkWidget *progress_bar;
-
-  headerbar = gtk_header_bar_new ();
-  gtk_header_bar_set_show_title_buttons (GTK_HEADER_BAR (headerbar), TRUE);
-
-  dialog = g_object_new (GTK_TYPE_WINDOW,
-                         "destroy-with-parent", TRUE,
-                         "transient-for", gtk_widget_get_root (GTK_WIDGET (page)),
-                         "titlebar", headerbar,
-                         "title", _("Privacy Policy"),
-                         "modal", TRUE,
-                         "default-width", 800,
-                         "default-height", 600,
-                         NULL);
-
-  overlay = gtk_overlay_new ();
-  gtk_window_set_child (GTK_WINDOW (dialog), overlay);
-
-  progress_bar = gtk_progress_bar_new ();
-  gtk_widget_add_css_class (progress_bar, "osd");
-  gtk_widget_set_halign (progress_bar, GTK_ALIGN_FILL);
-  gtk_widget_set_valign (progress_bar, GTK_ALIGN_START);
-  gtk_overlay_add_overlay (GTK_OVERLAY (overlay), progress_bar);
-
-  view = webkit_web_view_new ();
-  gtk_widget_set_hexpand (view, TRUE);
-  gtk_widget_set_vexpand (view, TRUE);
-  g_signal_connect (view, "notify::estimated-load-progress",
-                    G_CALLBACK (notify_progress_cb), progress_bar);
-  gtk_overlay_set_child (GTK_OVERLAY (overlay), view);
-
-  gtk_window_present (GTK_WINDOW (dialog));
-
-  webkit_web_view_load_uri (WEBKIT_WEB_VIEW (view), uri);
-
-  return TRUE;
-}
-#else
-static gboolean
-activate_link (GtkLabel       *label,
-               const gchar    *uri,
-               GisPrivacyPage *page)
-{
-  /* Fall back to default handler */
-  return FALSE;
-}
-#endif
-
 static gboolean
 update_os_data (GisPrivacyPage *page)
 {
@@ -195,13 +121,8 @@ gis_privacy_page_constructed (GObject *object)
   gtk_switch_set_active (GTK_SWITCH (page->location_switch), TRUE);
   gtk_switch_set_active (GTK_SWITCH (page->reporting_switch), TRUE);
 
-#ifdef HAVE_WEBKITGTK
-  gtk_label_set_markup (GTK_LABEL (page->location_privacy_label),
-                        _("Allows apps to determine your geographical location. Uses the Mozilla Location Service (<a href='https://location.services.mozilla.com/privacy'>privacy policy</a>)."));
-#else
   gtk_label_set_label (GTK_LABEL (page->location_privacy_label),
-                       _("Allows apps to determine your geographical location. Uses the Mozilla Location Service."));
-#endif
+                       _("Allows apps to determine your geographical location."));
 
   if (update_os_data (page))
     {
@@ -262,7 +183,7 @@ gis_privacy_page_class_init (GisPrivacyPageClass *klass)
   gtk_widget_class_bind_template_child (GTK_WIDGET_CLASS (klass), GisPrivacyPage, reporting_group);
   gtk_widget_class_bind_template_child (GTK_WIDGET_CLASS (klass), GisPrivacyPage, reporting_label);
   gtk_widget_class_bind_template_child (GTK_WIDGET_CLASS (klass), GisPrivacyPage, reporting_switch);
-  gtk_widget_class_bind_template_callback (GTK_WIDGET_CLASS (klass), activate_link);
+  gtk_widget_class_bind_template_callback (GTK_WIDGET_CLASS (klass), gis_activate_link);
 
   page_class->page_id = PAGE_ID;
   page_class->locale_changed = gis_privacy_page_locale_changed;
