@@ -114,6 +114,7 @@ gis_location_entry_init (GisLocationEntry *entry)
     priv = entry->priv = gis_location_entry_get_instance_private (entry);
 
     priv->entry = gtk_entry_new ();
+    gtk_entry_set_placeholder_text (GTK_ENTRY (priv->entry), _("Search cities"));
     gtk_widget_set_parent (priv->entry, GTK_WIDGET (entry));
     gtk_editable_init_delegate (GTK_EDITABLE (entry));
 
@@ -569,6 +570,10 @@ fill_location_entry_model (GtkListStore *store, GWeatherLocation *loc,
          */
     case GWEATHER_LOCATION_WEATHER_STATION:
         /* <location> with no parent <city> */
+        if (gweather_location_get_timezone (loc) == NULL) {
+            break;
+        }
+
         /* Translators: this is the name of a location followed by a region, for example:
          * 'London, United Kingdom'
          * You shouldn't need to translate this string unless the language has a different comma.
